// main11.cc is a part of the PYTHIA event generator.
// Copyright (C) 2012 Torbjorn Sjostrand.
// PYTHIA is licenced under the GNU GPL version 2, see COPYING for details.
// Please respect the MCnet Guidelines, see GUIDELINES for details.

// This is a simple test program. 
// It illustrates how Les Houches Event File input can be used in Pythia8.
// It uses the ttsample.lhe input file, the latter only with 100 events.

#include "Vincia.h"
//using namespace Pythia8; 
int main() {

  //************************************************************************
  // Define Pythia 8 generator with plug-in

  Pythia pythia;
  VinciaPlugin vincia(&pythia,"vincia_test_LHE.cmnd");

   //output file for data
  FILE *fout;

  fout=fopen("spins.dat","w");

  // Everything from here on is normal Pythia8
  // (with some slight extra functionality, such as post-run statistics from
  // Vincia and checking whether all events have unit weights)

  //************************************************************************

  // Shorthands
  Event& event = pythia.event;
  Settings& settings = pythia.settings;

  // Extract settings to be used in the main program.
  double eCM       = settings.parm("Beams:eCM");
  int    nEvent    = settings.mode("Main:numberOfEvents");
  int    nShow     = settings.mode("Main:timesToShow");
  bool   vinciaOn  = settings.flag("Vincia");
  int    verbose   = settings.mode("Vincia:verbose");
  int    iEventPri = -1;

  //************************************************************************

  // Initialize
  pythia.init( 11, -11, eCM);

  // List changed settings
  pythia.settings.listChanged();

  // Check that Z0 decay channels set correctly.
  pythia.particleData.listChanged();

  // Allow for possibility of a few faulty events.
  int nAbort = 10;
  int iAbort = 0;

  // Begin event loop; generate until none left in input file.     
  for (int iEvent = 0;iEvent < nEvent; ++iEvent) {

    if (iEvent%(max(1,nEvent/max(nShow,1))) == 0)
      cout << " Now begin event " << iEvent << endl;

    // Generate events, and check whether generation failed.
    if (!pythia.next()) {

      // If failure because reached end of file then exit event loop.
      if (pythia.info.atEndOfFile()) break; 

      // First few failures write off as "acceptable" errors, then quit.
      if (++iAbort < nAbort) continue;
      break;
    }

    double spin_sum = 0.0;
    double spin_tot = 0.0;

    for (int i = 0; i < pythia.event.size(); ++i) {
      if (pythia.event[i].isFinal() && pythia.event[i].pol() < 8) {
        spin_sum += pythia.event[i].pol();
        spin_tot += 1.0;
      }
    }
      if (spin_tot > 0.0) fprintf(fout,"%f %f %f\n",spin_sum,spin_sum/spin_tot,spin_tot);

//    if (iEvent < 3) event.list();

  // End of event loop.        
  }                                           

  fclose(fout);

  // Give statistics. Print histogram.
  pythia.stat();

  // Done.                           
  return 0;
}
